#
# spec file for package perl-Devel-GlobalDestruction
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Devel-GlobalDestruction
Name:           perl-Devel-GlobalDestruction
Version:        0.140.0
Release:        1.1
# 0.14 -> normalize -> 0.140.0
%define cpan_version 0.14
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Provides function returning the equivalent of ${^GLOBAL_PHASE} eq 'DESTR[cut]
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Sub::Exporter::Progressive) >= 0.001011
Requires:       perl(Sub::Exporter::Progressive) >= 0.001011
Provides:       perl(Devel::GlobalDestruction) = %{version}
Provides:       perl(ExtUtils::HasCompiler) = 0.16.0
%undefine       __perllib_provides
%{perl_requires}

%description
Perl's global destruction is a little tricky to deal with WRT finalizers
because it's not ordered and objects can sometimes disappear.

Writing defensive destructors is hard and annoying, and usually if global
destruction is happening you only need the destructors that free up non
process local resources to actually execute.

For these constructors you can avoid the mess by simply bailing out if
global destruction is in effect.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Tue May 20 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Tue Nov  1 2016 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-Devel-GlobalDestruction/Changes
  Revision history for Devel-GlobalDestruction
  0.14 - 2016-10-31
  - stop relying on . being in @INC
  - switch to ExtUtils::HasCompiler to detect presence of a compiler
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.13
  * include README
  * include minimum perl version 5.6 in metadata
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.12
  * Fix detection when loaded during global destruction by checking B::main_cv
  instead of B::main_start
  * Bump Sub::Exporter::Progressive dependency to fix loading in global
  destruction
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.11
  * Fix upgrading from version 0.09 or older
  * Rewrite pure-perl implementation in terms of B::main_start
    (greatly simplifies code)
  * Fix pure-perl behavior under $^C (RT#78619))
  * Separate XS portion into a compiler-optional dependency
    Devel::GlobalDestruction::XS
  * Rewrite completely broken pure-perl GD detection under threads
  * Fix pure-perl implementation incorrectly reporting GD during END phase
  * Switch to Sub::Exporter::Progressive
  * Actually detect errors in pure-perl test
  * Add prototype to pure-perl pre-5.14 version
  * De-retardize XS-less behavior under SpeedyCGI
  * Test suite now works from within space-containing paths
  * Pure-perl implementation for situations where neither ${^GLOBAL_PHASE} nor
    XS are available
* Tue Nov 29 2011 coolo@suse.com
- update to 0.04
  * To detect a perl with ${^GLOBAL_PHASE}, check for the feature
    itself instead of a specific perl version (doy).
  * Stop depending on Scope::Guard for the tests (doy).
  * Upgrade ppport.h from version 3.13 to 3.19.
* Fri Feb  4 2011 chris@computersalat.de
- recreated by cpanspec 1.78.03
- removed Author
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 11 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fixed deps
- bzipped Source
* Fri Oct 30 2009 pascal.bleser@opensuse.org
- initial package 0.02
